@@ -1,22 +1,30 @@
 """CoBib commands."""
 
 from .add import AddCommand
+from .delete import DeleteCommand
 from .edit import EditCommand
 from .export import ExportCommand
 from .init import InitCommand
 from .list import ListCommand
+from .modify import ModifyCommand
 from .open import OpenCommand
-from .delete import DeleteCommand
+from .redo import RedoCommand
+from .search import SearchCommand
 from .show import ShowCommand
+from .undo import UndoCommand
 
 
 __all__ = [
     "AddCommand",
+    "DeleteCommand",
     "EditCommand",
     "ExportCommand",
     "InitCommand",
     "ListCommand",
+    "ModifyCommand",
     "OpenCommand",
-    "DeleteCommand",
+    "RedoCommand",
+    "SearchCommand",
     "ShowCommand",
+    "UndoCommand",
     ]
