@@ -9,15 +9,29 @@ import sys
 
 LOGGER = logging.getLogger(__name__)
 
+ANSI_COLORS = [
+    'black',
+    'red',
+    'green',
+    'yellow',
+    'blue',
+    'magenta',
+    'cyan',
+    'white',
+]
+
 DEFAULTS = {
     'DATABASE': {
         'file': os.path.expanduser('~/.local/share/cobib/literature.yaml'),
+        'git': False,
         'open': 'xdg-open' if sys.platform.lower() == 'linux' else 'open',
         'grep': 'grep',
+        'search_ignore_case': False,
     },
     'FORMAT': {
         'month': 'int',
         'ignore_non_standard_types': False,
+        'default_entry_type': 'article',
     },
     'TUI': {
         'default_list_args': '-l',
@@ -44,6 +58,8 @@ DEFAULTS = {
         'popup_stdout_bg': 'blue',
         'popup_stderr_fg': 'white',
         'popup_stderr_bg': 'red',
+        'selection_fg': 'white',
+        'selection_bg': 'magenta',
     },
 }
 
@@ -97,10 +113,15 @@ class Config:
                      "Missing DATABASE section.")
         self._assert(isinstance(self.config.get('DATABASE', {}).get('file', None), str),
                      "DATABASE/file should be a string.")
+        self._assert(isinstance(self.config.get('DATABASE', {}).getboolean('git', None), bool),
+                     "DATABASE/git should be a boolean.")
         self._assert(isinstance(self.config.get('DATABASE', {}).get('open', None), str),
                      "DATABASE/open should be a string.")
         self._assert(isinstance(self.config.get('DATABASE', {}).get('grep', None), str),
                      "DATABASE/grep should be a string.")
+        self._assert(isinstance(
+            self.config.get('DATABASE', {}).getboolean('search_ignore_case', None), bool),
+                     "DATABASE/search_ignore_case should be a boolean.")
 
         # FORMAT section
         LOGGER.debug('Validing the FORMAT configuration section.')
@@ -111,6 +132,8 @@ class Config:
         self._assert(isinstance(
             self.config.get('FORMAT', {}).getboolean('ignore_non_standard_types', None), bool),
                      "FORMAT/ignore_non_standard_types should be a boolean.")
+        self._assert(isinstance(self.config.get('FORMAT', {}).get('default_entry_type', None), str),
+                     "FORMAT/default_entry_type should be a string.")
 
         # TUI section
         LOGGER.debug('Validing the TUI configuration section.')
@@ -143,10 +166,11 @@ class Config:
                          f"Missing value for COLORS/{name}")
         available_colors = ('black', 'red', 'green', 'yellow', 'blue', 'magenta', 'cyan', 'white')
         for name, color in self.config.get('COLORS', {}).items():
-            if name not in DEFAULTS['COLORS']:
+            if name not in DEFAULTS['COLORS'] and name not in available_colors:
                 LOGGER.warning('Ignoring unknown TUI color: %s', name)
             self._assert(color in available_colors or
-                         (len(color.strip('#')) == 6 and color.strip('#').isdigit()),
+                         (len(color.strip('#')) == 6 and
+                          tuple(int(color.strip('#')[i:i+2], 16) for i in (0, 2, 4))),
                          f"Unknown color specification: {color}")
 
     @staticmethod
@@ -159,5 +183,20 @@ class Config:
         if not expression:
             raise RuntimeError(error)
 
+    def get_ansi_color(self, name):
+        """Returns an ANSI color code for the named color.
+
+        Args:
+            name (str): a named color as specified in the configuration *excluding* the `_fg` or
+                        `_bg` suffix.
+
+        Returns:
+            A string representing the foreground and background ANSI color code.
+        """
+        fg_color = 30 + ANSI_COLORS.index(self.config['COLORS'].get(name + '_fg'))
+        bg_color = 40 + ANSI_COLORS.index(self.config['COLORS'].get(name + '_bg'))
+
+        return f'\x1b[{fg_color};{bg_color}m'
+
 
 CONFIG = Config()
