@@ -1,15 +1,16 @@
 """CoBib parsing module."""
 
 from collections import OrderedDict
+import json
 import logging
 import os
 import re
 import subprocess
+import sys
 
 from bs4 import BeautifulSoup
 from pylatexenc.latexencode import UnicodeToLatexEncoder
-from ruamel.yaml import YAML
-from ruamel.yaml.compat import StringIO
+from ruamel import yaml
 import bibtexparser
 import requests
 
@@ -20,10 +21,15 @@ LOGGER = logging.getLogger(__name__)
 # API and HEADER settings according to this resource: https://crosscite.org/docs.html
 DOI_URL = "https://doi.org/"
 DOI_HEADER = {'Accept': "application/x-bibtex"}
-# arXiv URL according to docs from here https://arxiv.org/help/oa
-ARXIV_URL = "https://export.arxiv.org/api/query?id_list="
 # DOI regex used for matching DOIs
 DOI_REGEX = r'(10\.[0-9a-zA-Z]+\/(?:(?!["&\'])\S)+)\b'
+# arXiv URL according to docs from here https://arxiv.org/help/oa
+ARXIV_URL = "https://export.arxiv.org/api/query?id_list="
+# ISBN regex used for matching ISBNs (adapted from https://github.com/xlcnd/isbnlib)
+ISBN_REGEX = re.compile(r'97[89]{1}(?:-?\d){10}|\d{9}[0-9X]{1}|'
+                        r'[-0-9X]{10,16}', re.I | re.M | re.S)
+# ISBN-API: https://openlibrary.org/dev/docs/api/books
+ISBN_URL = "https://openlibrary.org/api/books?bibkeys=ISBN:"
 # biblatex default types and required values taken from their docs: https://ctan.org/pkg/biblatex
 BIBTEX_TYPES = {
     'article': ['author', 'title', 'journal', 'year'],
@@ -41,7 +47,7 @@ class Entry:
 
     Handles everything ranging from field manipulation over format conversion to filter matching.
     """
-    class YamlDumper(YAML):
+    class YamlDumper(yaml.YAML):
         """Wrapper class for YAML dumping."""
 
         # pylint: disable=arguments-differ,inconsistent-return-statements
@@ -50,8 +56,8 @@ class Entry:
             inefficient = False
             if stream is None:
                 inefficient = True
-                stream = StringIO()
-            YAML.dump(self, data, stream, **kw)
+                stream = yaml.compat.StringIO()
+            yaml.YAML.dump(self, data, stream, **kw)
             if inefficient:
                 return stream.getvalue()
 
@@ -113,7 +119,11 @@ class Entry:
     @file.setter
     def set_file(self, file):
         """Sets the associated file of this entry."""
-        self.data['file'] = os.path.abspath(file)
+        if isinstance(file, list):
+            file = ', '.join([os.path.abspath(f) for f in file])
+        else:
+            file = os.path.abspath(file)
+        self.data['file'] = file
         LOGGER.debug("Adding '%s' as the file to '%s'.", self.data['file'], self.label)
 
     def convert_month(self, type_):
@@ -251,11 +261,11 @@ class Entry:
 
     def to_yaml(self):
         """Returns the entry in YAML format."""
-        yaml = Entry.YamlDumper()
-        yaml.explicit_start = True
-        yaml.explicit_end = True
+        yml = Entry.YamlDumper()
+        yml.explicit_start = True
+        yml.explicit_end = True
         LOGGER.debug('Converting entry %s to YAML format.', self.label)
-        return yaml.dump({self._label: dict(sorted(self.data.items()))})
+        return yml.dump({self._label: dict(sorted(self.data.items()))})
 
     @staticmethod
     def from_bibtex(file, string=False):
@@ -292,12 +302,12 @@ class Entry:
         Returns:
             An OrderedDict containing the bibliography as per the provided YAML file.
         """
-        yaml = YAML()
         bib = OrderedDict()
         LOGGER.debug('Loading YAML data from file: %s.', file)
-        for entry in yaml.load_all(file):
-            for label, data in entry.items():
-                bib[label] = Entry(label, data)
+        with open(file, 'r') as database:
+            for entry in yaml.safe_load_all(database):
+                for label, data in entry.items():
+                    bib[label] = Entry(label, data)
         return bib
 
     @staticmethod
@@ -310,9 +320,21 @@ class Entry:
         Returns:
             An OrderedDict containing the bibliographic data of the provided DOI.
         """
-        assert re.match(DOI_REGEX, doi)
+        try:
+            assert re.match(DOI_REGEX, doi)
+        except AssertionError:
+            msg = f"'{doi}' is not a valid DOI."
+            LOGGER.warning(msg)
+            print(msg, file=sys.stderr)
+            return {}
         LOGGER.info('Gathering BibTex data for DOI: %s.', doi)
-        page = requests.get(DOI_URL+doi, headers=DOI_HEADER, timeout=5)
+        try:
+            page = requests.get(DOI_URL+doi, headers=DOI_HEADER, timeout=10)
+        except requests.exceptions.ReadTimeout as exc:
+            msg = 'The DOI API timed out: ' + str(exc)
+            LOGGER.warning(msg)
+            print(msg, file=sys.stderr)
+            return {}
         return Entry.from_bibtex(page.text, string=True)
 
     @staticmethod
@@ -328,13 +350,15 @@ class Entry:
         LOGGER.info('Gathering BibTex data for arXiv ID: %s.', arxiv)
         page = requests.get(ARXIV_URL+arxiv)
         xml = BeautifulSoup(page.text, features='html.parser')
-        # TODO rewrite this to use a defaultdict(str)
+        if xml.feed.entry.title.contents[0] == 'Error':
+            msg = 'The arXiv API returned the following error: ' + \
+                  xml.feed.entry.summary.contents[0]
+            LOGGER.warning(msg)
+            print(msg, file=sys.stderr)
+            return {}
         entry = {}
         entry['archivePrefix'] = 'arXiv'
         for key in xml.feed.entry.findChildren(recursive=False):
-            # TODO key.name == 'category'
-            # TODO key.name == 'link'
-            # TODO key.name == 'updated'
             if key.name == 'arxiv:doi':
                 entry['doi'] = str(key.contents[0])
             elif key.name == 'id':
@@ -343,11 +367,14 @@ class Entry:
             elif key.name == 'primary_category':
                 entry['primaryClass'] = str(key.attrs['term'])
             elif key.name == 'published':
-                entry['year'] = key.contents[0].split('-')[0]
+                # The year must also be stored as a string for compatibility reasons with
+                # bibtexparser. However, we perform a conversion to an integer first, to ensure that
+                # the year can actually be represented as such.
+                entry['year'] = str(int(key.contents[0].split('-')[0]))
                 if 'ID' in entry.keys():
-                    entry['ID'] = entry['ID'] + entry['year']
+                    entry['ID'] = entry['ID'] + str(entry['year'])
                 else:
-                    entry['ID'] = entry['year']
+                    entry['ID'] = str(entry['year'])
             elif key.name == 'title':
                 entry['title'] = re.sub(r'\s+', ' ', key.contents[0].strip().replace('\n', ' '))
             elif key.name == 'author':
@@ -375,3 +402,56 @@ class Entry:
         bib = OrderedDict()
         bib[entry['ID']] = Entry(entry['ID'], entry)
         return bib
+
+    @staticmethod
+    def from_isbn(isbn):
+        """Queries the bibtex source for a given ISBN.
+
+        Args:
+            isbn (str): ISBN for which to obtain the bibtex data.
+
+        Returns:
+            An OrderedDict containing the bibliographic data of the provided ISBN.
+        """
+        assert re.match(ISBN_REGEX, isbn)
+        LOGGER.info('Gathering BibTex data for ISBN: %s.', isbn)
+        isbn_plain = ''.join([i for i in isbn if i.isdigit()])
+        page = requests.get(ISBN_URL+isbn_plain+'&jscmd=data&format=json', timeout=5)
+        contents = dict(json.loads(page.content))
+        if not contents:
+            msg = f'No data was found for ISBN: {isbn}. If you think this is an error and the ' + \
+                  'openlibrary API should provide an entry, please file a bug report. Otherwise' + \
+                  ' please try adding this entry manually until more APIs are available in CoBib.'
+            LOGGER.warning(msg)
+            print(msg, file=sys.stderr)
+            return {}
+        entry = {}
+        for key, value in contents[list(contents.keys())[0]].items():
+            if key in ['title', 'url']:
+                entry[key] = value
+            elif key == 'number_of_pages':
+                # we explicitly convert to a string to prevent type errors in the bibtexparser
+                entry['pages'] = str(value)
+            elif key == 'publish_date':
+                entry['date'] = value
+                try:
+                    entry['year'] = re.search(r'\d{4}', value).group()
+                    if 'ID' in entry.keys():
+                        entry['ID'] += str(entry['year'])
+                    else:
+                        entry['ID'] = str(entry['year'])
+                except AttributeError:
+                    pass
+            elif key == 'authors':
+                if 'ID' in entry.keys():
+                    entry['ID'] = value[0]['name'].split()[-1] + entry['ID']
+                else:
+                    entry['ID'] = value[0]['name'].split()[-1]
+                entry['author'] = ' and'.join([a['name'] for a in value])
+            elif key == 'publishers':
+                entry['publisher'] = ' and'.join([a['name'] for a in value])
+        # set entry-type do 'book'
+        entry['ENTRYTYPE'] = 'book'
+        bib = OrderedDict()
+        bib[entry['ID']] = Entry(entry['ID'], entry)
+        return bib
