@@ -55,11 +55,15 @@ def assert_list_view(screen, current, expected):
     assert screen.display[-1].strip() == ""
 
 
-def assert_help_screen(screen):
+def assert_help_screen(screen, only_title=False):
     """Asserts the contents of the Help screen."""
-    assert "CoBib TUI Help" in screen.display[2]
-    for cmd, desc in TUI.HELP_DICT.items():
-        assert any("{:<8} {}".format(cmd+':', desc) in line for line in screen.display[4:21])
+    header_check = ["CoBib TUI Help" in line for line in screen.display]
+    assert any(header_check)
+    if not only_title:
+        offset = header_check.index(True)
+        for cmd, desc in TUI.HELP_DICT.items():
+            assert any("{:<8} {}".format(cmd+':', desc) in line for line in
+                       screen.display[2+offset:19+offset])
 
 
 def assert_no_help_window_artefacts(screen):
@@ -143,10 +147,9 @@ def assert_editor(screen):
             assert source_line.strip() in screen_line.strip()
 
 
-def assert_export(screen, contents):
-    """Asserts the export prompt."""
+def assert_prompt(screen, contents):
+    """Asserts the prompt line contents."""
     assert screen.display[-1].strip() == contents
-    # actual command execution is tested by the test_commands.test_export unittest
 
 
 def assert_search_view(screen, label, search, selected):
@@ -202,8 +205,9 @@ def assert_select_show_view(screen, current):
         ['a-b ./test/example_entry.bib\n', assert_add, {}],
         ['d', assert_delete, {}],
         ['Ge', assert_editor, {}],
-        ['x', assert_export, {'contents': ":export"}],
-        ['x' + 100 * 'j', assert_export, {'contents': 'j' * 79}],  # regression-test on #48
+        ['x', assert_prompt, {'contents': ":export"}],
+        [':', assert_prompt, {'contents': ":"}],
+        [':' + 100 * 'j', assert_prompt, {'contents': 'j' * 79}],  # regression-test on #48
         ['f++ID einstein\n', assert_list_view, {
             'current': 1, 'expected': ['einstein']}],
         ['f--ID einstein\n', assert_list_view, {
@@ -396,8 +400,24 @@ def test_tui_open_menu():
         DeleteCommand().execute(['dummy_multi_file_entry'])
 
 
-def test_tui_resize(setup):
-    """Test TUI resize handling."""
+@pytest.mark.parametrize(['keys', 'assertion', 'assertion_kwargs'], [
+        ['', assert_list_view, {
+            'current': 1, 'expected': [
+                'dummy_entry_for_scroll_testing', 'knuthwebsite', 'latexcompanion', 'einstein'
+            ]}],
+        ['?', assert_help_screen, {'only_title': True}],
+    ])
+def test_tui_resize(setup, keys, assertion, assertion_kwargs):
+    """Test TUI resize handling.
+
+    Includes a regression test against #58 by opening the help popup.
+
+    Args:
+        setup: runs pytest fixture.
+        keys (str): keys to be send to the CoBib TUI.
+        assertion (Callable): function to run the assertions for the key to be tested.
+        assertion_kwargs (dict): additional keyword arguments for assertion function.
+    """
     # create pseudo-terminal
     pid, f_d = os.forkpty()
     if pid == 0:
@@ -405,10 +425,13 @@ def test_tui_resize(setup):
         curses.wrapper(TUI)
     else:
         # resize pseudo terminal
-        fcntl.ioctl(f_d, termios.TIOCSWINSZ, array('h', [10, 120, 1200, 220]))
+        fcntl.ioctl(f_d, termios.TIOCSWINSZ, array('h', [10, 45, 1200, 220]))
         # parent process sets up virtual screen of identical size
-        screen = pyte.Screen(120, 10)
+        screen = pyte.Screen(45, 10)
         stream = pyte.ByteStream(screen)
+        # send keys char-wise to TUI
+        for key in keys:
+            os.write(f_d, str.encode(key))
         # scrape pseudo-terminal's screen
         while True:
             try:
@@ -427,11 +450,7 @@ def test_tui_resize(setup):
                     break
         for line in screen.display:
             print(line)
-        assert_list_view(screen, 1, [
-            'dummy_entry_for_scroll_testing', 'knuthwebsite', 'latexcompanion', 'einstein'
-        ])
-        # the terminal should be wide enough to contain the full information text
-        assert screen.display[-2].strip() == TUI.infoline()
+        assertion(screen, **assertion_kwargs)
 
 
 @pytest.mark.parametrize(['keys', 'assertion', 'assertion_kwargs'], [
